@@ -40,11 +40,11 @@ func TestMatchingExceptions(t *testing.T) {
 	cfg := defaultConfig()
 
 	if delta := cfg.RegistriesSkippingTagResolving.Difference(shared.DigestResolutionExceptions); delta.Len() > 0 {
-		t.Errorf("Got extra: %v", delta.List())
+		t.Error("Got extra:", delta.List())
 	}
 
 	if delta := shared.DigestResolutionExceptions.Difference(cfg.RegistriesSkippingTagResolving); delta.Len() > 0 {
-		t.Errorf("Didn't get: %v", delta.List())
+		t.Error("Didn't get:", delta.List())
 	}
 }
 
